@@ -27,12 +27,12 @@ class AnnotationException(Exception):
 
 class AnnotationNotFound(AnnotationException):
     def getMessage(self):
-        return "Annotation was not found in the XML file: %s" % (self.path + [self.name])
+        return f"Annotation was not found in the XML file: {self.path} -> {self.name}"
 
 
 class AnnotationInvalid(AnnotationException):
     def getMessage(self):
-        return "Annotation is invalid: %s" % (self.path)
+        return f"Annotation is invalid: {self.path}"
 
 
 class ChannelsNotPresent(Exception):
@@ -40,10 +40,7 @@ class ChannelsNotPresent(Exception):
 
     def __init__(self, channels, msg=None, recordid="Unknown"):
         if msg is None:
-            msg = (
-                "Channels of record %s where not present: %s, you can define 'aliases' for the channelname or make the channel optional"
-                % (recordid, channels)
-            )
+            msg = f"Channels of record {recordid} where not present: {channels}, you can define 'aliases' for the channelname or make the channel optional"
         super().__init__(msg)
         self.channels = channels
 
